"""Plotly theme to ROSS - Rotordynamic Open Source Sofware."""

from plotly import graph_objects as go
from plotly import io as pio

# tableau colors
tableau_colors = {
    "blue": "#1f77b4",
    "orange": "#ff7f0e",
    "green": "#2ca02c",
    "red": "#d62728",
    "purple": "#9467bd",
    "brown": "#8c564b",
    "pink": "#e377c2",
    "gray": "#7f7f7f",
    "olive": "#bcbd22",
    "cyan": "#17becf",
}
pio.templates["ross"] = go.layout.Template(
    layout={
        "annotationdefaults": {
            "arrowcolor": "#2a3f5f",
            "arrowhead": 0,
            "arrowwidth": 1,
        },
        "coloraxis": {"colorbar": {"outlinewidth": 0, "ticks": ""}},
        "colorscale": {
            "diverging": [
                [0, "#8e0152"],
                [0.1, "#c51b7d"],
                [0.2, "#de77ae"],
                [0.3, "#f1b6da"],
                [0.4, "#fde0ef"],
                [0.5, "#f7f7f7"],
                [0.6, "#e6f5d0"],
                [0.7, "#b8e186"],
                [0.8, "#7fbc41"],
                [0.9, "#4d9221"],
                [1, "#276419"],
            ],
            "sequential": [
                [0.0, "#0d0887"],
                [0.1111111111111111, "#46039f"],
                [0.2222222222222222, "#7201a8"],
                [0.3333333333333333, "#9c179e"],
                [0.4444444444444444, "#bd3786"],
                [0.5555555555555556, "#d8576b"],
                [0.6666666666666666, "#ed7953"],
                [0.7777777777777778, "#fb9f3a"],
                [0.8888888888888888, "#fdca26"],
                [1.0, "#f0f921"],
            ],
            "sequentialminus": [
                [0.0, "#0d0887"],
                [0.1111111111111111, "#46039f"],
                [0.2222222222222222, "#7201a8"],
                [0.3333333333333333, "#9c179e"],
                [0.4444444444444444, "#bd3786"],
                [0.5555555555555556, "#d8576b"],
                [0.6666666666666666, "#ed7953"],
                [0.7777777777777778, "#fb9f3a"],
                [0.8888888888888888, "#fdca26"],
                [1.0, "#f0f921"],
            ],
        },
        "colorway": list(tableau_colors.values()),
        "font": {"color": "#2a3f5f"},
        "geo": {
            "bgcolor": "white",
            "lakecolor": "white",
            "landcolor": "white",
            "showlakes": True,
            "showland": True,
            "subunitcolor": "#C8D4E3",
        },
        "hoverlabel": {"align": "left"},
        "hovermode": "closest",
        "mapbox": {"style": "light"},
        "paper_bgcolor": "white",
        "plot_bgcolor": "white",
        "polar": {
            "angularaxis": {
                "gridcolor": "#EBF0F8",
                "linecolor": "#EBF0F8",
                "ticks": "",
            },
            "bgcolor": "white",
            "radialaxis": {"gridcolor": "#EBF0F8", "linecolor": "#EBF0F8", "ticks": ""},
        },
        "scene": {
            "xaxis": {
                "backgroundcolor": "white",
                "gridcolor": "#DFE8F3",
                "gridwidth": 2,
                "linecolor": "#EBF0F8",
                "showbackground": True,
                "ticks": "",
                "zerolinecolor": "#EBF0F8",
                "showspikes": False,
            },
            "yaxis": {
                "backgroundcolor": "white",
                "gridcolor": "#DFE8F3",
                "gridwidth": 2,
                "linecolor": "#EBF0F8",
                "showbackground": True,
                "ticks": "",
                "zerolinecolor": "#EBF0F8",
                "showspikes": False,
            },
            "zaxis": {
                "backgroundcolor": "white",
                "gridcolor": "#DFE8F3",
                "gridwidth": 2,
                "linecolor": "#EBF0F8",
                "showbackground": True,
                "ticks": "",
                "zerolinecolor": "#EBF0F8",
                "showspikes": False,
            },
            "camera": {
                "up": {"x": 0, "y": 0, "z": 1},
                "center": {"x": 0, "y": 0, "z": 0},
                "eye": {"x": 2.0, "y": 2.0, "z": 2.0},
            },
        },
        "shapedefaults": {"line": {"color": "#2a3f5f"}},
        "ternary": {
            "aaxis": {"gridcolor": "#DFE8F3", "linecolor": "#A2B1C6", "ticks": ""},
            "baxis": {"gridcolor": "#DFE8F3", "linecolor": "#A2B1C6", "ticks": ""},
            "bgcolor": "white",
            "caxis": {"gridcolor": "#DFE8F3", "linecolor": "#A2B1C6", "ticks": ""},
        },
        "title": {"x": 0.05},
        "xaxis": {
            "automargin": True,
            "gridcolor": "#EBF0F8",
            "showline": True,
            "linecolor": "black",
            "linewidth": 2.0,
            "mirror": True,
            "ticks": "",
            "title": {"standoff": 15},
            "zeroline": False,
            "zerolinecolor": "#EBF0F8",
            "zerolinewidth": 2,
        },
        "yaxis": {
            "automargin": True,
            "gridcolor": "#EBF0F8",
            "showline": True,
            "linecolor": "black",
            "linewidth": 2.0,
            "mirror": True,
            "ticks": "",
            "title": {"standoff": 15},
            "zeroline": False,
            "zerolinecolor": "#EBF0F8",
            "zerolinewidth": 2,
        },
    },
    data={
        "bar": [
            {
                "error_x": {"color": "#2a3f5f"},
                "error_y": {"color": "#2a3f5f"},
                "marker": {"line": {"color": "white", "width": 0.5}},
                "type": "bar",
            }
        ],
        "barpolar": [
            {"marker": {"line": {"color": "white", "width": 0.5}}, "type": "barpolar"}
        ],
        "carpet": [
            {
                "aaxis": {
                    "endlinecolor": "#2a3f5f",
                    "gridcolor": "#C8D4E3",
                    "linecolor": "#C8D4E3",
                    "minorgridcolor": "#C8D4E3",
                    "startlinecolor": "#2a3f5f",
                },
                "baxis": {
                    "endlinecolor": "#2a3f5f",
                    "gridcolor": "#C8D4E3",
                    "linecolor": "#C8D4E3",
                    "minorgridcolor": "#C8D4E3",
                    "startlinecolor": "#2a3f5f",
                },
                "type": "carpet",
            }
        ],
        "choropleth": [
            {"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "choropleth"}
        ],
        "contour": [
            {
                "colorbar": {"outlinewidth": 0, "ticks": ""},
                "colorscale": [
                    [0.0, "#0d0887"],
                    [0.1111111111111111, "#46039f"],
                    [0.2222222222222222, "#7201a8"],
                    [0.3333333333333333, "#9c179e"],
                    [0.4444444444444444, "#bd3786"],
                    [0.5555555555555556, "#d8576b"],
                    [0.6666666666666666, "#ed7953"],
                    [0.7777777777777778, "#fb9f3a"],
                    [0.8888888888888888, "#fdca26"],
                    [1.0, "#f0f921"],
                ],
                "type": "contour",
            }
        ],
        "contourcarpet": [
            {"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "contourcarpet"}
        ],
        "heatmap": [
            {
                "colorbar": {"outlinewidth": 0, "ticks": ""},
                "colorscale": [
                    [0.0, "#0d0887"],
                    [0.1111111111111111, "#46039f"],
                    [0.2222222222222222, "#7201a8"],
                    [0.3333333333333333, "#9c179e"],
                    [0.4444444444444444, "#bd3786"],
                    [0.5555555555555556, "#d8576b"],
                    [0.6666666666666666, "#ed7953"],
                    [0.7777777777777778, "#fb9f3a"],
                    [0.8888888888888888, "#fdca26"],
                    [1.0, "#f0f921"],
                ],
                "type": "heatmap",
            }
        ],
        "heatmapgl": [
            {
                "colorbar": {"outlinewidth": 0, "ticks": ""},
                "colorscale": [
                    [0.0, "#0d0887"],
                    [0.1111111111111111, "#46039f"],
                    [0.2222222222222222, "#7201a8"],
                    [0.3333333333333333, "#9c179e"],
                    [0.4444444444444444, "#bd3786"],
                    [0.5555555555555556, "#d8576b"],
                    [0.6666666666666666, "#ed7953"],
                    [0.7777777777777778, "#fb9f3a"],
                    [0.8888888888888888, "#fdca26"],
                    [1.0, "#f0f921"],
                ],
                "type": "heatmapgl",
            }
        ],
        "histogram": [
            {
                "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}},
                "type": "histogram",
            }
        ],
        "histogram2d": [
            {
                "colorbar": {"outlinewidth": 0, "ticks": ""},
                "colorscale": [
                    [0.0, "#0d0887"],
                    [0.1111111111111111, "#46039f"],
                    [0.2222222222222222, "#7201a8"],
                    [0.3333333333333333, "#9c179e"],
                    [0.4444444444444444, "#bd3786"],
                    [0.5555555555555556, "#d8576b"],
                    [0.6666666666666666, "#ed7953"],
                    [0.7777777777777778, "#fb9f3a"],
                    [0.8888888888888888, "#fdca26"],
                    [1.0, "#f0f921"],
                ],
                "type": "histogram2d",
            }
        ],
        "histogram2dcontour": [
            {
                "colorbar": {"outlinewidth": 0, "ticks": ""},
                "colorscale": [
                    [0.0, "#0d0887"],
                    [0.1111111111111111, "#46039f"],
                    [0.2222222222222222, "#7201a8"],
                    [0.3333333333333333, "#9c179e"],
                    [0.4444444444444444, "#bd3786"],
                    [0.5555555555555556, "#d8576b"],
                    [0.6666666666666666, "#ed7953"],
                    [0.7777777777777778, "#fb9f3a"],
                    [0.8888888888888888, "#fdca26"],
                    [1.0, "#f0f921"],
                ],
                "type": "histogram2dcontour",
            }
        ],
        "mesh3d": [{"colorbar": {"outlinewidth": 0, "ticks": ""}, "type": "mesh3d"}],
        "parcoords": [
            {
                "line": {"colorbar": {"outlinewidth": 0, "ticks": ""}},
                "type": "parcoords",
            }
        ],
        "pie": [{"automargin": True, "type": "pie"}],
        "scatter": [
            {
                "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}},
                "type": "scatter",
            }
        ],
        "scatter3d": [
            {
                "line": {"colorbar": {"outlinewidth": 0, "ticks": ""}},
                "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}, "size": 4},
                "type": "scatter3d",
            }
        ],
        "scattercarpet": [
            {
                "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}},
                "type": "scattercarpet",
            }
        ],
        "scattergeo": [
            {
                "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}},
                "type": "scattergeo",
            }
        ],
        "scattergl": [
            {
                "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}},
                "type": "scattergl",
            }
        ],
        "scattermapbox": [
            {
                "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}},
                "type": "scattermapbox",
            }
        ],
        "scatterpolar": [
            {
                "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}},
                "type": "scatterpolar",
            }
        ],
        "scatterpolargl": [
            {
                "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}},
                "type": "scatterpolargl",
            }
        ],
        "scatterternary": [
            {
                "marker": {"colorbar": {"outlinewidth": 0, "ticks": ""}},
                "type": "scatterternary",
            }
        ],
        "surface": [
            {
                "colorbar": {"outlinewidth": 0, "ticks": ""},
                "colorscale": [
                    [0.0, "#0d0887"],
                    [0.1111111111111111, "#46039f"],
                    [0.2222222222222222, "#7201a8"],
                    [0.3333333333333333, "#9c179e"],
                    [0.4444444444444444, "#bd3786"],
                    [0.5555555555555556, "#d8576b"],
                    [0.6666666666666666, "#ed7953"],
                    [0.7777777777777778, "#fb9f3a"],
                    [0.8888888888888888, "#fdca26"],
                    [1.0, "#f0f921"],
                ],
                "type": "surface",
            }
        ],
        "table": [
            {
                "cells": {"fill": {"color": "#EBF0F8"}, "line": {"color": "white"}},
                "header": {"fill": {"color": "#C8D4E3"}, "line": {"color": "white"}},
                "type": "table",
            }
        ],
    },
)

# coolwarm colormap

coolwarm_r = [
    [0.0, "rgb(179,3,38)"],
    [0.003937007874015748, "rgb(181,8,39)"],
    [0.007874015748031496, "rgb(182,13,40)"],
    [0.011811023622047244, "rgb(184,17,41)"],
    [0.015748031496062992, "rgb(185,22,42)"],
    [0.01968503937007874, "rgb(187,26,43)"],
    [0.023622047244094488, "rgb(188,31,44)"],
    [0.027559055118110236, "rgb(190,35,45)"],
    [0.031496062992125984, "rgb(191,40,46)"],
    [0.03543307086614173, "rgb(193,42,48)"],
    [0.03937007874015748, "rgb(194,45,49)"],
    [0.04330708661417323, "rgb(196,48,50)"],
    [0.047244094488188976, "rgb(197,50,51)"],
    [0.051181102362204724, "rgb(198,53,52)"],
    [0.05511811023622047, "rgb(200,56,53)"],
    [0.05905511811023622, "rgb(201,59,55)"],
    [0.06299212598425197, "rgb(202,61,56)"],
    [0.06692913385826772, "rgb(204,63,57)"],
    [0.07086614173228346, "rgb(205,66,58)"],
    [0.07480314960629922, "rgb(206,68,60)"],
    [0.07874015748031496, "rgb(207,70,61)"],
    [0.08267716535433071, "rgb(209,73,62)"],
    [0.08661417322834646, "rgb(210,75,63)"],
    [0.09055118110236221, "rgb(211,77,64)"],
    [0.09448818897637795, "rgb(212,79,66)"],
    [0.0984251968503937, "rgb(214,82,67)"],
    [0.10236220472440945, "rgb(215,84,68)"],
    [0.1062992125984252, "rgb(216,86,70)"],
    [0.11023622047244094, "rgb(217,88,71)"],
    [0.1141732283464567, "rgb(218,90,72)"],
    [0.11811023622047244, "rgb(219,92,74)"],
    [0.1220472440944882, "rgb(220,94,75)"],
    [0.12598425196850394, "rgb(221,96,76)"],
    [0.12992125984251968, "rgb(222,98,78)"],
    [0.13385826771653545, "rgb(223,100,79)"],
    [0.1377952755905512, "rgb(224,102,80)"],
    [0.14173228346456693, "rgb(225,104,82)"],
    [0.14566929133858267, "rgb(226,106,83)"],
    [0.14960629921259844, "rgb(227,108,84)"],
    [0.15354330708661418, "rgb(228,110,86)"],
    [0.15748031496062992, "rgb(229,112,87)"],
    [0.16141732283464566, "rgb(230,114,89)"],
    [0.16535433070866143, "rgb(230,116,90)"],
    [0.16929133858267717, "rgb(231,117,92)"],
    [0.1732283464566929, "rgb(232,119,93)"],
    [0.17716535433070865, "rgb(233,121,94)"],
    [0.18110236220472442, "rgb(234,123,96)"],
    [0.18503937007874016, "rgb(234,125,97)"],
    [0.1889763779527559, "rgb(235,127,99)"],
    [0.19291338582677164, "rgb(236,128,100)"],
    [0.1968503937007874, "rgb(236,130,102)"],
    [0.20078740157480315, "rgb(237,132,103)"],
    [0.2047244094488189, "rgb(238,134,105)"],
    [0.20866141732283464, "rgb(238,135,106)"],
    [0.2125984251968504, "rgb(239,137,108)"],
    [0.21653543307086615, "rgb(240,139,109)"],
    [0.2204724409448819, "rgb(240,141,111)"],
    [0.22440944881889763, "rgb(241,142,112)"],
    [0.2283464566929134, "rgb(241,144,114)"],
    [0.23228346456692914, "rgb(242,145,115)"],
    [0.23622047244094488, "rgb(242,147,117)"],
    [0.24015748031496062, "rgb(243,149,118)"],
    [0.2440944881889764, "rgb(243,150,120)"],
    [0.24803149606299213, "rgb(243,152,121)"],
    [0.25196850393700787, "rgb(244,154,123)"],
    [0.2559055118110236, "rgb(244,155,124)"],
    [0.25984251968503935, "rgb(244,157,126)"],
    [0.2637795275590551, "rgb(245,158,127)"],
    [0.2677165354330709, "rgb(245,160,129)"],
    [0.27165354330708663, "rgb(245,161,130)"],
    [0.2755905511811024, "rgb(246,163,132)"],
    [0.2795275590551181, "rgb(246,164,134)"],
    [0.28346456692913385, "rgb(246,166,135)"],
    [0.2874015748031496, "rgb(246,167,137)"],
    [0.29133858267716534, "rgb(246,169,138)"],
    [0.2952755905511811, "rgb(246,170,140)"],
    [0.2992125984251969, "rgb(246,171,141)"],
    [0.3031496062992126, "rgb(247,173,143)"],
    [0.30708661417322836, "rgb(247,174,145)"],
    [0.3110236220472441, "rgb(247,176,146)"],
    [0.31496062992125984, "rgb(247,177,148)"],
    [0.3188976377952756, "rgb(247,178,149)"],
    [0.3228346456692913, "rgb(247,179,151)"],
    [0.32677165354330706, "rgb(247,181,152)"],
    [0.33070866141732286, "rgb(246,182,154)"],
    [0.3346456692913386, "rgb(246,183,156)"],
    [0.33858267716535434, "rgb(246,185,157)"],
    [0.3425196850393701, "rgb(246,186,159)"],
    [0.3464566929133858, "rgb(246,187,160)"],
    [0.35039370078740156, "rgb(246,188,162)"],
    [0.3543307086614173, "rgb(246,189,164)"],
    [0.35826771653543305, "rgb(245,191,165)"],
    [0.36220472440944884, "rgb(245,192,167)"],
    [0.3661417322834646, "rgb(245,193,168)"],
    [0.3700787401574803, "rgb(244,194,170)"],
    [0.37401574803149606, "rgb(244,195,171)"],
    [0.3779527559055118, "rgb(244,196,173)"],
    [0.38188976377952755, "rgb(243,197,175)"],
    [0.3858267716535433, "rgb(243,198,176)"],
    [0.38976377952755903, "rgb(242,199,178)"],
    [0.3937007874015748, "rgb(242,200,179)"],
    [0.39763779527559057, "rgb(242,201,181)"],
    [0.4015748031496063, "rgb(241,202,182)"],
    [0.40551181102362205, "rgb(241,203,184)"],
    [0.4094488188976378, "rgb(240,204,185)"],
    [0.41338582677165353, "rgb(239,205,187)"],
    [0.41732283464566927, "rgb(239,206,188)"],
    [0.421259842519685, "rgb(238,207,190)"],
    [0.4251968503937008, "rgb(237,207,192)"],
    [0.42913385826771655, "rgb(237,208,193)"],
    [0.4330708661417323, "rgb(236,209,195)"],
    [0.43700787401574803, "rgb(236,210,196)"],
    [0.4409448818897638, "rgb(235,211,198)"],
    [0.4448818897637795, "rgb(234,211,199)"],
    [0.44881889763779526, "rgb(233,212,201)"],
    [0.452755905511811, "rgb(232,213,202)"],
    [0.4566929133858268, "rgb(231,214,204)"],
    [0.46062992125984253, "rgb(231,214,205)"],
    [0.4645669291338583, "rgb(230,215,207)"],
    [0.468503937007874, "rgb(229,216,208)"],
    [0.47244094488188976, "rgb(228,216,209)"],
    [0.4763779527559055, "rgb(227,217,211)"],
    [0.48031496062992124, "rgb(226,217,212)"],
    [0.484251968503937, "rgb(225,218,214)"],
    [0.4881889763779528, "rgb(224,218,215)"],
    [0.4921259842519685, "rgb(223,219,217)"],
    [0.49606299212598426, "rgb(222,219,218)"],
    [0.5, "rgb(220,220,221)"],
    [0.5039370078740157, "rgb(219,220,222)"],
    [0.5078740157480315, "rgb(218,220,223)"],
    [0.5118110236220472, "rgb(217,220,224)"],
    [0.515748031496063, "rgb(216,219,225)"],
    [0.5196850393700787, "rgb(215,219,226)"],
    [0.5236220472440944, "rgb(214,219,228)"],
    [0.5275590551181102, "rgb(213,219,229)"],
    [0.531496062992126, "rgb(211,219,230)"],
    [0.5354330708661418, "rgb(210,218,231)"],
    [0.5393700787401575, "rgb(209,218,232)"],
    [0.5433070866141733, "rgb(208,218,233)"],
    [0.547244094488189, "rgb(207,217,234)"],
    [0.5511811023622047, "rgb(206,217,235)"],
    [0.5551181102362205, "rgb(205,217,236)"],
    [0.5590551181102362, "rgb(204,216,237)"],
    [0.562992125984252, "rgb(202,216,238)"],
    [0.5669291338582677, "rgb(201,215,238)"],
    [0.5708661417322834, "rgb(200,215,239)"],
    [0.5748031496062992, "rgb(199,214,240)"],
    [0.5787401574803149, "rgb(198,214,241)"],
    [0.5826771653543307, "rgb(197,213,242)"],
    [0.5866141732283464, "rgb(195,213,242)"],
    [0.5905511811023622, "rgb(194,212,243)"],
    [0.594488188976378, "rgb(193,212,244)"],
    [0.5984251968503937, "rgb(192,211,245)"],
    [0.6023622047244095, "rgb(190,211,245)"],
    [0.6062992125984252, "rgb(189,210,246)"],
    [0.610236220472441, "rgb(188,209,246)"],
    [0.6141732283464567, "rgb(187,209,247)"],
    [0.6181102362204725, "rgb(185,208,248)"],
    [0.6220472440944882, "rgb(184,207,248)"],
    [0.6259842519685039, "rgb(183,207,249)"],
    [0.6299212598425197, "rgb(182,206,249)"],
    [0.6338582677165354, "rgb(180,205,250)"],
    [0.6377952755905512, "rgb(179,204,250)"],
    [0.6417322834645669, "rgb(178,203,251)"],
    [0.6456692913385826, "rgb(176,203,251)"],
    [0.6496062992125984, "rgb(175,202,251)"],
    [0.6535433070866141, "rgb(174,201,252)"],
    [0.65748031496063, "rgb(172,200,252)"],
    [0.6614173228346457, "rgb(171,199,252)"],
    [0.6653543307086615, "rgb(170,198,253)"],
    [0.6692913385826772, "rgb(168,197,253)"],
    [0.6732283464566929, "rgb(167,196,253)"],
    [0.6771653543307087, "rgb(166,195,253)"],
    [0.6811023622047244, "rgb(164,194,254)"],
    [0.6850393700787402, "rgb(163,193,254)"],
    [0.6889763779527559, "rgb(162,192,254)"],
    [0.6929133858267716, "rgb(160,191,254)"],
    [0.6968503937007874, "rgb(159,190,254)"],
    [0.7007874015748031, "rgb(157,189,254)"],
    [0.7047244094488189, "rgb(156,188,254)"],
    [0.7086614173228346, "rgb(155,187,254)"],
    [0.7125984251968503, "rgb(153,186,254)"],
    [0.7165354330708661, "rgb(152,185,254)"],
    [0.7204724409448819, "rgb(151,184,254)"],
    [0.7244094488188977, "rgb(149,183,254)"],
    [0.7283464566929134, "rgb(148,181,254)"],
    [0.7322834645669292, "rgb(146,180,254)"],
    [0.7362204724409449, "rgb(145,179,254)"],
    [0.7401574803149606, "rgb(144,178,254)"],
    [0.7440944881889764, "rgb(142,177,253)"],
    [0.7480314960629921, "rgb(141,175,253)"],
    [0.7519685039370079, "rgb(139,174,253)"],
    [0.7559055118110236, "rgb(138,173,253)"],
    [0.7598425196850394, "rgb(137,172,252)"],
    [0.7637795275590551, "rgb(135,170,252)"],
    [0.7677165354330708, "rgb(134,169,252)"],
    [0.7716535433070866, "rgb(133,168,251)"],
    [0.7755905511811023, "rgb(131,166,251)"],
    [0.7795275590551181, "rgb(130,165,251)"],
    [0.7834645669291339, "rgb(128,164,250)"],
    [0.7874015748031497, "rgb(127,162,250)"],
    [0.7913385826771654, "rgb(126,161,249)"],
    [0.7952755905511811, "rgb(124,160,249)"],
    [0.7992125984251969, "rgb(123,158,248)"],
    [0.8031496062992126, "rgb(122,157,248)"],
    [0.8070866141732284, "rgb(120,155,247)"],
    [0.8110236220472441, "rgb(119,154,246)"],
    [0.8149606299212598, "rgb(117,152,246)"],
    [0.8188976377952756, "rgb(116,151,245)"],
    [0.8228346456692913, "rgb(115,149,244)"],
    [0.8267716535433071, "rgb(113,148,244)"],
    [0.8307086614173228, "rgb(112,147,243)"],
    [0.8346456692913385, "rgb(111,145,242)"],
    [0.8385826771653543, "rgb(109,144,241)"],
    [0.84251968503937, "rgb(108,142,241)"],
    [0.8464566929133859, "rgb(107,141,240)"],
    [0.8503937007874016, "rgb(105,139,239)"],
    [0.8543307086614174, "rgb(104,137,238)"],
    [0.8582677165354331, "rgb(103,136,237)"],
    [0.8622047244094488, "rgb(101,134,236)"],
    [0.8661417322834646, "rgb(100,133,235)"],
    [0.8700787401574803, "rgb(99,131,234)"],
    [0.8740157480314961, "rgb(97,130,234)"],
    [0.8779527559055118, "rgb(96,128,232)"],
    [0.8818897637795275, "rgb(95,126,231)"],
    [0.8858267716535433, "rgb(93,125,230)"],
    [0.889763779527559, "rgb(92,123,229)"],
    [0.8937007874015748, "rgb(91,121,228)"],
    [0.8976377952755905, "rgb(90,120,227)"],
    [0.9015748031496063, "rgb(88,118,226)"],
    [0.905511811023622, "rgb(87,117,225)"],
    [0.9094488188976378, "rgb(86,115,224)"],
    [0.9133858267716536, "rgb(85,113,222)"],
    [0.9173228346456693, "rgb(83,112,221)"],
    [0.9212598425196851, "rgb(82,110,220)"],
    [0.9251968503937008, "rgb(81,108,219)"],
    [0.9291338582677166, "rgb(80,107,218)"],
    [0.9330708661417323, "rgb(78,105,216)"],
    [0.937007874015748, "rgb(77,103,215)"],
    [0.9409448818897638, "rgb(76,102,214)"],
    [0.9448818897637795, "rgb(75,100,212)"],
    [0.9488188976377953, "rgb(73,98,211)"],
    [0.952755905511811, "rgb(72,96,209)"],
    [0.9566929133858267, "rgb(71,95,208)"],
    [0.9606299212598425, "rgb(70,93,207)"],
    [0.9645669291338582, "rgb(69,91,205)"],
    [0.968503937007874, "rgb(67,90,204)"],
    [0.9724409448818898, "rgb(66,88,202)"],
    [0.9763779527559056, "rgb(65,86,201)"],
    [0.9803149606299213, "rgb(64,84,199)"],
    [0.984251968503937, "rgb(63,83,198)"],
    [0.9881889763779528, "rgb(62,81,196)"],
    [0.9921259842519685, "rgb(60,79,195)"],
    [0.9960629921259843, "rgb(59,77,193)"],
    [1.0, "rgb(58,76,192)"],
]
